@@ -62,14 +62,18 @@ Use the 'directory' notation with exactly one trailing slash (like 'http://examp
         @classmethod
         def mbd_meta_add_debian(cls, msglog):
             "Add internet Debian archive sources."
-            for url in ["http://httpredir.debian.org/debian/",            # Debian releases
-                        "http://ftp.debian.org/debian/",                  # Debian releases
-                        "http://httpredir.debian.org/debian-backports/",  # Debian backports, <= squeeze
-                        "http://backports.debian.org/debian-backports/",  # Debian backports, <= squeeze
-                        "http://httpredir.debian.org/debian-archive/",    # Archived Debian releases
-                        "http://archive.debian.org/debian/",              # Archived Debian releases
-                        "http://archive.debian.org/backports.org/",       # Archived (sarge, etch, lenny) backports
-                        ]:
+            for url in ["http://ftp.debian.org/debian/",                                 # Debian Releases
+                        "http://httpredir.debian.org/debian/",                           # alt: httpredir
+                        "http://ftp.de.debian.org/debian/",                              # alt: full mirror
+
+                        "http://archive.debian.org/debian/",                             # Archived Debian Releases
+                        "http://httpredir.debian.org/debian-archive/debian/",            # alt: httpredir
+                        "http://ftp.de.debian.org/debian-archive/debian/",               # alt: full mirror
+
+                        "http://archive.debian.org/debian-backports/",                   # Archived Debian Backports
+                        "http://httpredir.debian.org/debian-archive/debian-backports/",  # alt: httpredir
+                        "http://ftp.de.debian.org/debian-archive/debian-backports/",     # alt: full mirror
+                       ]:
                 cls._mbd_get_or_create(msglog, url)
             msglog.info("Consider adding archives with your local or closest mirrors; check 'netselect-apt'.")
 
@@ -78,7 +82,7 @@ Use the 'directory' notation with exactly one trailing slash (like 'http://examp
             "Add internet Ubuntu archive sources."
             for url in ["http://archive.ubuntu.com/ubuntu/",              # Ubuntu releases
                         "http://old-releases.ubuntu.com/ubuntu/",         # Older Ubuntu release
-                        ]:
+                       ]:
                 cls._mbd_get_or_create(msglog, url)
             msglog.info("Consider replacing these archives with you closest mirror(s); check netselect-apt.")
 
@@ -86,7 +90,7 @@ Use the 'directory' notation with exactly one trailing slash (like 'http://examp
         return "{u} (ping {p} ms)".format(u=self.url, p=self.ping)
 
     def clean(self, *args, **kwargs):
-        if self.url[-1] != "/" or self.url[-2] == "/":
+        if self.url[-1] != "/" or self.url[-2] == "/":  # pylint: disable=unsubscriptable-object
             raise django.core.exceptions.ValidationError("The URL must have exactly one trailing slash (like 'http://example.org/path/').")
         super(Archive, self).clean(*args, **kwargs)
 
